class StatusError(Exception):
    """Bot Status Error"""

    def __init__(self, *args: object) -> None:
        super().__init__(*args)


class ContainerNameError(Exception):
    """Bot Status Error"""

    def __init__(self, *args: object) -> None:
        super().__init__(*args)
